@@ -5,5 +5,5 @@ mod options;
 mod sort;
 
 pub use color::PColor;
-pub use options::{Mode, Options, DEFAULT_BLACK, DEFAULT_BRIGHTNESS, DEFAULT_WHITE};
+pub use options::{Direction, Mode, Options, DEFAULT_BLACK, DEFAULT_BRIGHTNESS, DEFAULT_WHITE};
 pub use sort::{sort, sort_with_options};
