@@ -3,19 +3,23 @@ use once_cell::sync::Lazy;
 use crate::PColor;
 
 /// Options to configure behaviours.
-#[derive(Clone, Debug, Eq, PartialEq)]
+#[derive(Clone, Debug, Default, Eq, PartialEq)]
 pub struct Options {
     /// Sorting mode.
     pub mode: Mode,
+
+    /// Sorting direction.
+    pub direction: Direction,
 }
 
-impl Default for Options {
-    fn default() -> Self {
-        Self {
-            mode: Default::default(),
-        }
-    }
-}
+/// Default value of [`Mode::Black`].
+pub static DEFAULT_BLACK: Lazy<PColor> = Lazy::new(|| PColor::new(11, 220, 0));
+
+/// Default value of [`Mode::Brightness`].
+pub static DEFAULT_BRIGHTNESS: u8 = 60;
+
+/// Default value of [`Mode::White`].
+pub static DEFAULT_WHITE: Lazy<PColor> = Lazy::new(|| PColor::new(57, 162, 192));
 
 /// Sorting modes.
 #[derive(Clone, Debug, Eq, PartialEq)]
@@ -36,10 +40,6 @@ impl Default for Mode {
     }
 }
 
-pub static DEFAULT_BLACK: Lazy<PColor> = Lazy::new(|| PColor::new(11, 220, 0));
-pub static DEFAULT_BRIGHTNESS: u8 = 60;
-pub static DEFAULT_WHITE: Lazy<PColor> = Lazy::new(|| PColor::new(57, 162, 192));
-
 impl Mode {
     /// Black mode with a default threshold.
     pub fn black() -> Self {
@@ -57,6 +57,43 @@ impl Mode {
     }
 }
 
+/// Sorting direction.
+#[derive(Clone, Debug, Eq, PartialEq)]
+pub enum Direction {
+    /// Both column and row.
+    Both,
+
+    /// Only column.
+    Column,
+
+    /// Only row.
+    Row,
+}
+
+impl Default for Direction {
+    fn default() -> Self {
+        Direction::Both
+    }
+}
+
+impl Direction {
+    /// Checks if this direction has [`Direction::Column`].
+    pub fn has_column(&self) -> bool {
+        match self {
+            Self::Both | Self::Column => true,
+            _ => false,
+        }
+    }
+
+    /// Checks if this direction has [`Direction::Row`].
+    pub fn has_row(&self) -> bool {
+        match self {
+            Self::Both | Self::Row => true,
+            _ => false,
+        }
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -65,6 +102,7 @@ mod tests {
     fn test_options_default() {
         let expected = Options {
             mode: Mode::Brightness(60),
+            direction: Direction::Both,
         };
         assert_eq!(expected, Options::default());
     }
@@ -95,4 +133,24 @@ mod tests {
         let expected = Mode::White(color);
         assert_eq!(expected, Mode::white());
     }
+
+    #[test]
+    fn test_direction_default() {
+        let expected = Direction::Both;
+        assert_eq!(expected, Direction::default());
+    }
+
+    #[test]
+    fn test_direction_has_column() {
+        assert!(Direction::Both.has_column());
+        assert!(Direction::Column.has_column());
+        assert!(!Direction::Row.has_column());
+    }
+
+    #[test]
+    fn test_direction_has_row() {
+        assert!(Direction::Both.has_row());
+        assert!(!Direction::Column.has_row());
+        assert!(Direction::Row.has_row());
+    }
 }
